# freebayes

**DOI:** [10.5281/zenodo.10259219](https://doi.org/10.5281/zenodo.10259219)

## Available Versions
- **Version 1.3.7**
  - [Download](https://zenodo.org/record/10259220/files/freebayes_1.3.7.img)
  - **MD5:** `63e7667f034116050bf300adb53acbf0`
  - **DOI:** [10.5281/zenodo.10259220](https://doi.org/10.5281/zenodo.10259220)
  - **Size:** 171.18 MB
  - **Binaries:** 0 available

- **Version 1.2.0**
  - [Download](https://zenodo.org/record/10259279/files/freebayes_1.2.0.img)
  - **MD5:** `667bb29636f140670cd8d105d6bf0ea8`
  - **DOI:** [10.5281/zenodo.10259279](https://doi.org/10.5281/zenodo.10259279)
  - **Size:** 227.43 MB
  - **Binaries:** 0 available

- **Version 1.3.9**
  - [Download](https://zenodo.org/record/14930911/files/freebayes_1.3.9.img)
  - **MD5:** `e2dd4d83971fc8fe9909a8e3f5f59d26`
  - **DOI:** [10.5281/zenodo.14930911](https://doi.org/10.5281/zenodo.14930911)
  - **Size:** 184.62 MB
  - **Binaries:** 10 available

## Binaries (7 total)

```freebayes vcffirstheader vcfstreamsort vcfuniq parallel freebayes-parallel fasta_generate_regions.py```
